import { Container, TextField, InputAdornment, Link, Button } from "@mui/material";
import React, { useState, useEffect, useRef } from 'react';
import PhoneIphoneIcon from '@mui/icons-material/PhoneIphone';
import LockIcon from '@mui/icons-material/Lock';
import { useSelector, useDispatch } from 'react-redux'
import { setAccount, setVerificationCode } from "../business/userSlice.js"
import yzs from "../business/request.js";
import Agreement from "./Agreement.js";

export default function ({ udid, agreeAgreement, onAgreeChange }) {
    const dispatch = useDispatch();
    const code = useRef(null);
    const [seconds, setSeconds] = useState(0);   // 倒计时

    const account = useSelector(state => state.user.account)
    const verificationCode = useSelector(state => state.user.verificationCode)

    const handleInputChange = (event) => {
        const { name, value } = event.target;
        if (name === 'username') dispatch(setAccount(value));
        if (name === 'password') dispatch(setVerificationCode(value));
    };

    useEffect(() => {
        const timer = window.setInterval(() => {
            if (seconds > 0) {
                setSeconds(seconds - 1);
            } else {
                code.current.disabled = false;
            }
        }, 1000);
        return () => {
            window.clearInterval(timer);
        };
    }, [seconds]);

    const onClick = (event) => {
        event.preventDefault();
        code.current.disabled = true;
        yzs.send_phone_code(udid, account)
        setSeconds(60);
    };

    return <Container disableGutters={true}
        sx={{
            width: 300,
            height: 200,
        }}
    >
        <TextField
            name="username"
            autoComplete="username"
            label="请输入手机号码"
            variant="outlined"
            value={account}
            color="primary"
            fullWidth
            onChange={handleInputChange}
            InputProps={{
                startAdornment: (
                    <InputAdornment position="start">
                        <PhoneIphoneIcon />
                    </InputAdornment>
                ),
            }}
        />
        <TextField
            // sx={{ paddingTop: 4 }}
            fullWidth
            margin="normal"
            name="password"
            label="请输入验证码"
            type="password"
            autoComplete="current-password"
            variant="outlined"
            value={verificationCode}
            onChange={handleInputChange}
            InputProps={{
                startAdornment: (
                    <InputAdornment position="start">
                        <LockIcon />
                    </InputAdornment>
                ),

                endAdornment: <InputAdornment position="end">
                    <Link ref={code}
                        color={seconds > 0 ? "#FFB3B3" : "red"}
                        component="button" underline="none" onClick={onClick}>{seconds > 0 ? `重新发送(${seconds})` : "发送动态码"}</Link>
                </InputAdornment>
            }}
        />
        <Button
            type="submit"
            variant="contained"
            color="primary"
            fullWidth
            disabled={!agreeAgreement}
            sx={{
                backgroundColor: "#FF595A",
                '&:hover': {
                    backgroundColor: '#FF595A',
                },
                '&:active': {
                    backgroundColor: '#FF595A',
                },
            }}
        >
            注册/登录
        </Button>
        <Agreement agree={agreeAgreement} onChange={onAgreeChange} />
    </Container>
}